<%include file="/pageheader.html"/> <%! from kaithem.src import messagelogging from kaithem.src import messagebus from kaithem.src.unitsofmeasure import format_time_interval,strftime import time import quart from kaithem.src.util import url,saferepr from kaithem.src.config import config def dump(j): return saferepr(j) %>

## Recently active topics

Topics that have been posted to recently are shown here. Only topics marked with (logging) will be saved when data is dumped. only the ${config['non_logged_topic_limit']} most recent entries will be saved. You can change this in the configuration.. To log a topic, edit the text list at the bottom or click start logging. Log files will be dumped after a certain number of messages, or when the server state is explicitly saved.

| Show only topics containing:

<% rev = False if 'sort' in quart.request.args: if quart.request.args['sort'] == 'time': sortkey = lambda x: messagelogging.log[x][-1][0] rev = True else: sortkey = lambda x: x else: sortkey = lambda x: x %> There are ${len(messagelogging.log)|h} recent topics. Sorting:[Alphabetical|Most Recently Active]
%if messagelogging.log: %for i in sorted(messagelogging.log.keys(),key=sortkey,reverse = rev):

Latest Value |
    ${dump(messagelogging.log[i][-1][1])|h}
Most Recent Message Posted at: | ${strftime(messagelogging.log[i][-1][0])} (${format_time_interval(time.time()-messagelogging.log[i][-1][0],1)} ago)
Total Messages Available: | ${len(messagelogging.log[i])}View History

%endfor
%endif
<%include file="/pagefooter.html"/>